@@ -12,7 +12,7 @@
 #              style files of BibTeX 0.99.
 # CREATED    : 1997/09/21, Greg Ward
 # MODIFIED   : 
-# VERSION    : $Id: Bib.pm 670 2000-03-23 02:08:40Z greg $
+# VERSION    : $Id: Bib.pm 3033 2006-09-21 20:07:27Z ambs $
 # COPYRIGHT  : Copyright (c) 1997-2000 by Gregory P. Ward.  All rights
 #              reserved.
 # 
@@ -291,6 +291,8 @@ Constrained fields: at most one of C<volume>, C<number>.
 
 =item C<inproceedings>
 
+=item C<conference>
+
 Required fields: C<author>, C<title>, C<booktitle>, C<year>.
 Optional fields: C<editor>, C<series>, C<pages>, C<address>, C<month>, C<organization>, C<publisher>, C<note>.
 Constrained fields: at most one of C<volume>, C<number>.
@@ -391,6 +393,11 @@ sub describe_entry
                       [qw(editor series pages address month 
                           organization publisher note)],
                       [0, 1, [qw(volume number)]]);
+   $self->set_fields ('conference',
+                      [qw(author title booktitle year)],
+                      [qw(editor series pages address month 
+                          organization publisher note)],
+                      [0, 1, [qw(volume number)]]);
    $self->set_fields ('manual',
                       [qw(title)],
                       [qw(author organization address edition 
